@@ -2,14 +2,14 @@
 
 ## Coercions
 setAs("matrix", "binaryRatingMatrix",
-	function(from) new("binaryRatingMatrix", 
+	function(from) new("binaryRatingMatrix",
 		data = as(from, "itemMatrix")))
 
 setAs("binaryRatingMatrix", "matrix",
 	function(from) as(from@data, "matrix"))
 
 setAs("itemMatrix", "binaryRatingMatrix",
-	function(from) new("binaryRatingMatrix", 
+	function(from) new("binaryRatingMatrix",
 		data = from))
 
 setAs("binaryRatingMatrix", "itemMatrix",
@@ -55,15 +55,15 @@ setMethod(".splitKnownUnknown", signature(data="binaryRatingMatrix"),
 		## given might of length one or length(data)
 		if(length(given)==1) given <- rep(given, nrow(data))
 		nitems <- rowCounts(data)
-		
+
 		allBut <- given < 0
 		if(any(allBut)) {
 		  given[allBut] <- nitems[allBut] + given[allBut]
 		}
-		  
-		if(any(given>nitems)) stop("Not enough ratings for user" , 
-		  paste(which(given>nitems), collapse = ", ")) 
-		
+
+		if(any(given>nitems)) stop("Not enough ratings for user" ,
+		  paste(which(given>nitems), collapse = ", "))
+
 		l <- getList(data, decode=FALSE)
 		known_index <- lapply(1:length(l),
 			FUN = function(i) sample(1:length(l[[i]]), given[i]))
@@ -72,12 +72,13 @@ setMethod(".splitKnownUnknown", signature(data="binaryRatingMatrix"),
 			lapply(1:length(l), FUN = function(x)
 				l[[x]][known_index[[x]]]),
 			itemLabels = itemLabels(data@data))
+    rownames(known) <- rownames(data)
 
 		unknown <- encode(
 			lapply(1:length(l), FUN = function(x)
 				l[[x]][-known_index[[x]]]),
 			itemLabels = itemLabels(data@data))
-
+    rownames(unknown) <- rownames(data)
 
 		known <- new("binaryRatingMatrix", data = known)
 		unknown <- new("binaryRatingMatrix", data = unknown)
